# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateCustomerModuleMetaInfoRequest(DaraModel):
    def __init__(
        self,
        customer_module_id: int = None,
        feature_string: str = None,
        feature_template: str = None,
    ):
        # Customer model ID.
        self.customer_module_id = customer_module_id
        # A string representation of List<Object>, where Object has the following structure:
        # {
        # "mappingName": "xxx"
        # }
        self.feature_string = feature_string
        # Version of the feature adopted.
        self.feature_template = feature_template

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.customer_module_id is not None:
            result['CustomerModuleId'] = self.customer_module_id

        if self.feature_string is not None:
            result['FeatureString'] = self.feature_string

        if self.feature_template is not None:
            result['FeatureTemplate'] = self.feature_template

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomerModuleId') is not None:
            self.customer_module_id = m.get('CustomerModuleId')

        if m.get('FeatureString') is not None:
            self.feature_string = m.get('FeatureString')

        if m.get('FeatureTemplate') is not None:
            self.feature_template = m.get('FeatureTemplate')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._apply_bastion_account_request import ApplyBastionAccountRequest
from ._apply_bastion_account_response_body import ApplyBastionAccountResponseBody
from ._apply_bastion_account_response import ApplyBastionAccountResponse
from ._associate_poc_task_request import AssociatePocTaskRequest
from ._associate_poc_task_response_body import AssociatePocTaskResponseBody
from ._associate_poc_task_response import AssociatePocTaskResponse
from ._complete_modeling_project_request import CompleteModelingProjectRequest
from ._complete_modeling_project_response_body import CompleteModelingProjectResponseBody
from ._complete_modeling_project_response import CompleteModelingProjectResponse
from ._create_customer_module_basic_info_request import CreateCustomerModuleBasicInfoRequest
from ._create_customer_module_basic_info_response_body import CreateCustomerModuleBasicInfoResponseBody
from ._create_customer_module_basic_info_response import CreateCustomerModuleBasicInfoResponse
from ._create_customer_module_meta_info_request import CreateCustomerModuleMetaInfoRequest
from ._create_customer_module_meta_info_response_body import CreateCustomerModuleMetaInfoResponseBody
from ._create_customer_module_meta_info_response import CreateCustomerModuleMetaInfoResponse
from ._create_customer_module_output_info_request import CreateCustomerModuleOutputInfoRequest
from ._create_customer_module_output_info_response_body import CreateCustomerModuleOutputInfoResponseBody
from ._create_customer_module_output_info_response import CreateCustomerModuleOutputInfoResponse
from ._create_modeling_project_request import CreateModelingProjectRequest
from ._create_modeling_project_response_body import CreateModelingProjectResponseBody
from ._create_modeling_project_response import CreateModelingProjectResponse
from ._delete_model_request import DeleteModelRequest
from ._delete_model_response_body import DeleteModelResponseBody
from ._delete_model_response import DeleteModelResponse
from ._deploy_model_file_request import DeployModelFileRequest
from ._deploy_model_file_response_body import DeployModelFileResponseBody
from ._deploy_model_file_response import DeployModelFileResponse
from ._describe_customer_module_basic_info_request import DescribeCustomerModuleBasicInfoRequest
from ._describe_customer_module_basic_info_response_body import DescribeCustomerModuleBasicInfoResponseBody
from ._describe_customer_module_basic_info_response import DescribeCustomerModuleBasicInfoResponse
from ._describe_customer_module_meta_info_request import DescribeCustomerModuleMetaInfoRequest
from ._describe_customer_module_meta_info_response_body import DescribeCustomerModuleMetaInfoResponseBody
from ._describe_customer_module_meta_info_response import DescribeCustomerModuleMetaInfoResponse
from ._describe_customer_module_output_info_request import DescribeCustomerModuleOutputInfoRequest
from ._describe_customer_module_output_info_response_body import DescribeCustomerModuleOutputInfoResponseBody
from ._describe_customer_module_output_info_response import DescribeCustomerModuleOutputInfoResponse
from ._describe_feature_option_request import DescribeFeatureOptionRequest
from ._describe_feature_option_response_body import DescribeFeatureOptionResponseBody
from ._describe_feature_option_response import DescribeFeatureOptionResponse
from ._describe_feature_template_list_response_body import DescribeFeatureTemplateListResponseBody
from ._describe_feature_template_list_response import DescribeFeatureTemplateListResponse
from ._describe_file_download_url_request import DescribeFileDownloadUrlRequest
from ._describe_file_download_url_response_body import DescribeFileDownloadUrlResponseBody
from ._describe_file_download_url_response import DescribeFileDownloadUrlResponse
from ._describe_model_feature_request import DescribeModelFeatureRequest
from ._describe_model_feature_response_body import DescribeModelFeatureResponseBody
from ._describe_model_feature_response import DescribeModelFeatureResponse
from ._describe_model_oss_token_response_body import DescribeModelOssTokenResponseBody
from ._describe_model_oss_token_response import DescribeModelOssTokenResponse
from ._describe_modeling_project_detail_request import DescribeModelingProjectDetailRequest
from ._describe_modeling_project_detail_response_body import DescribeModelingProjectDetailResponseBody
from ._describe_modeling_project_detail_response import DescribeModelingProjectDetailResponse
from ._describe_modeling_project_list_request import DescribeModelingProjectListRequest
from ._describe_modeling_project_list_response_body import DescribeModelingProjectListResponseBody
from ._describe_modeling_project_list_response import DescribeModelingProjectListResponse
from ._describe_module_service_exist_request import DescribeModuleServiceExistRequest
from ._describe_module_service_exist_response_body import DescribeModuleServiceExistResponseBody
from ._describe_module_service_exist_response import DescribeModuleServiceExistResponse
from ._describe_module_status_request import DescribeModuleStatusRequest
from ._describe_module_status_response_body import DescribeModuleStatusResponseBody
from ._describe_module_status_response import DescribeModuleStatusResponse
from ._describe_poc_task_list_response_body import DescribePocTaskListResponseBody
from ._describe_poc_task_list_response import DescribePocTaskListResponse
from ._describe_saf_rmmp_order_response_body import DescribeSafRmmpOrderResponseBody
from ._describe_saf_rmmp_order_response import DescribeSafRmmpOrderResponse
from ._describe_service_and_scene_request import DescribeServiceAndSceneRequest
from ._describe_service_and_scene_response_body import DescribeServiceAndSceneResponseBody
from ._describe_service_and_scene_response import DescribeServiceAndSceneResponse
from ._describe_user_model_list_request import DescribeUserModelListRequest
from ._describe_user_model_list_response_body import DescribeUserModelListResponseBody
from ._describe_user_model_list_response import DescribeUserModelListResponse
from ._duplicate_model_request import DuplicateModelRequest
from ._duplicate_model_response_body import DuplicateModelResponseBody
from ._duplicate_model_response import DuplicateModelResponse
from ._edit_model_request import EditModelRequest
from ._edit_model_response_body import EditModelResponseBody
from ._edit_model_response import EditModelResponse
from ._get_bastion_host_certification_request import GetBastionHostCertificationRequest
from ._get_bastion_host_certification_response_body import GetBastionHostCertificationResponseBody
from ._get_bastion_host_certification_response import GetBastionHostCertificationResponse
from ._iterate_model_request import IterateModelRequest
from ._iterate_model_response_body import IterateModelResponseBody
from ._iterate_model_response import IterateModelResponse
from ._offline_model_request import OfflineModelRequest
from ._offline_model_response_body import OfflineModelResponseBody
from ._offline_model_response import OfflineModelResponse
from ._online_model_request import OnlineModelRequest
from ._online_model_response_body import OnlineModelResponseBody
from ._online_model_response import OnlineModelResponse
from ._parse_expression_parameters_request import ParseExpressionParametersRequest
from ._parse_expression_parameters_response_body import ParseExpressionParametersResponseBody
from ._parse_expression_parameters_response import ParseExpressionParametersResponse
from ._prepublish_model_request import PrepublishModelRequest
from ._prepublish_model_response_body import PrepublishModelResponseBody
from ._prepublish_model_response import PrepublishModelResponse
from ._request_model_file_sync_request import RequestModelFileSyncRequest
from ._request_model_file_sync_response_body import RequestModelFileSyncResponseBody
from ._request_model_file_sync_response import RequestModelFileSyncResponse
from ._rollback_model_request import RollbackModelRequest
from ._rollback_model_response_body import RollbackModelResponseBody
from ._rollback_model_response import RollbackModelResponse
from ._test_model_request import TestModelRequest
from ._test_model_response_body import TestModelResponseBody
from ._test_model_response import TestModelResponse
from ._test_pre_model_request import TestPreModelRequest
from ._test_pre_model_response_body import TestPreModelResponseBody
from ._test_pre_model_response import TestPreModelResponse
from ._test_process_expression_request import TestProcessExpressionRequest
from ._test_process_expression_response_body import TestProcessExpressionResponseBody
from ._test_process_expression_response import TestProcessExpressionResponse
from ._update_module_basic_info_request import UpdateModuleBasicInfoRequest
from ._update_module_basic_info_response_body import UpdateModuleBasicInfoResponseBody
from ._update_module_basic_info_response import UpdateModuleBasicInfoResponse
from ._validate_model_file_request import ValidateModelFileRequest
from ._validate_model_file_response_body import ValidateModelFileResponseBody
from ._validate_model_file_response import ValidateModelFileResponse
from ._validate_test_file_request import ValidateTestFileRequest
from ._validate_test_file_response_body import ValidateTestFileResponseBody
from ._validate_test_file_response import ValidateTestFileResponse
from ._create_modeling_project_response_body import CreateModelingProjectResponseBodyResultObject
from ._describe_customer_module_basic_info_response_body import DescribeCustomerModuleBasicInfoResponseBodyResultObject
from ._describe_customer_module_meta_info_response_body import DescribeCustomerModuleMetaInfoResponseBodyResultObjectFeatureList
from ._describe_customer_module_meta_info_response_body import DescribeCustomerModuleMetaInfoResponseBodyResultObject
from ._describe_customer_module_output_info_response_body import DescribeCustomerModuleOutputInfoResponseBodyResultObject
from ._describe_feature_option_response_body import DescribeFeatureOptionResponseBodyResultObject
from ._describe_feature_template_list_response_body import DescribeFeatureTemplateListResponseBodyResultObject
from ._describe_model_feature_response_body import DescribeModelFeatureResponseBodyResultObject
from ._describe_model_oss_token_response_body import DescribeModelOssTokenResponseBodyResultObject
from ._describe_modeling_project_detail_response_body import DescribeModelingProjectDetailResponseBodyResultObjectPocTasks
from ._describe_modeling_project_detail_response_body import DescribeModelingProjectDetailResponseBodyResultObjectSyncedFilesFiles
from ._describe_modeling_project_detail_response_body import DescribeModelingProjectDetailResponseBodyResultObjectSyncedFiles
from ._describe_modeling_project_detail_response_body import DescribeModelingProjectDetailResponseBodyResultObject
from ._describe_modeling_project_list_response_body import DescribeModelingProjectListResponseBodyResultObject
from ._describe_poc_task_list_response_body import DescribePocTaskListResponseBodyResultObject
from ._describe_saf_rmmp_order_response_body import DescribeSafRmmpOrderResponseBodyResultObject
from ._describe_service_and_scene_response_body import DescribeServiceAndSceneResponseBodyResultObject
from ._describe_user_model_list_response_body import DescribeUserModelListResponseBodyResultObject
from ._parse_expression_parameters_response_body import ParseExpressionParametersResponseBodyResultObject
from ._test_model_response_body import TestModelResponseBodyResultObjectTestResult
from ._test_model_response_body import TestModelResponseBodyResultObject
from ._test_process_expression_response_body import TestProcessExpressionResponseBodyResultObject
from ._validate_model_file_response_body import ValidateModelFileResponseBodyResultObject
from ._validate_test_file_response_body import ValidateTestFileResponseBodyResultObject

__all__ = [
    ApplyBastionAccountRequest,
    ApplyBastionAccountResponseBody,
    ApplyBastionAccountResponse,
    AssociatePocTaskRequest,
    AssociatePocTaskResponseBody,
    AssociatePocTaskResponse,
    CompleteModelingProjectRequest,
    CompleteModelingProjectResponseBody,
    CompleteModelingProjectResponse,
    CreateCustomerModuleBasicInfoRequest,
    CreateCustomerModuleBasicInfoResponseBody,
    CreateCustomerModuleBasicInfoResponse,
    CreateCustomerModuleMetaInfoRequest,
    CreateCustomerModuleMetaInfoResponseBody,
    CreateCustomerModuleMetaInfoResponse,
    CreateCustomerModuleOutputInfoRequest,
    CreateCustomerModuleOutputInfoResponseBody,
    CreateCustomerModuleOutputInfoResponse,
    CreateModelingProjectRequest,
    CreateModelingProjectResponseBody,
    CreateModelingProjectResponse,
    DeleteModelRequest,
    DeleteModelResponseBody,
    DeleteModelResponse,
    DeployModelFileRequest,
    DeployModelFileResponseBody,
    DeployModelFileResponse,
    DescribeCustomerModuleBasicInfoRequest,
    DescribeCustomerModuleBasicInfoResponseBody,
    DescribeCustomerModuleBasicInfoResponse,
    DescribeCustomerModuleMetaInfoRequest,
    DescribeCustomerModuleMetaInfoResponseBody,
    DescribeCustomerModuleMetaInfoResponse,
    DescribeCustomerModuleOutputInfoRequest,
    DescribeCustomerModuleOutputInfoResponseBody,
    DescribeCustomerModuleOutputInfoResponse,
    DescribeFeatureOptionRequest,
    DescribeFeatureOptionResponseBody,
    DescribeFeatureOptionResponse,
    DescribeFeatureTemplateListResponseBody,
    DescribeFeatureTemplateListResponse,
    DescribeFileDownloadUrlRequest,
    DescribeFileDownloadUrlResponseBody,
    DescribeFileDownloadUrlResponse,
    DescribeModelFeatureRequest,
    DescribeModelFeatureResponseBody,
    DescribeModelFeatureResponse,
    DescribeModelOssTokenResponseBody,
    DescribeModelOssTokenResponse,
    DescribeModelingProjectDetailRequest,
    DescribeModelingProjectDetailResponseBody,
    DescribeModelingProjectDetailResponse,
    DescribeModelingProjectListRequest,
    DescribeModelingProjectListResponseBody,
    DescribeModelingProjectListResponse,
    DescribeModuleServiceExistRequest,
    DescribeModuleServiceExistResponseBody,
    DescribeModuleServiceExistResponse,
    DescribeModuleStatusRequest,
    DescribeModuleStatusResponseBody,
    DescribeModuleStatusResponse,
    DescribePocTaskListResponseBody,
    DescribePocTaskListResponse,
    DescribeSafRmmpOrderResponseBody,
    DescribeSafRmmpOrderResponse,
    DescribeServiceAndSceneRequest,
    DescribeServiceAndSceneResponseBody,
    DescribeServiceAndSceneResponse,
    DescribeUserModelListRequest,
    DescribeUserModelListResponseBody,
    DescribeUserModelListResponse,
    DuplicateModelRequest,
    DuplicateModelResponseBody,
    DuplicateModelResponse,
    EditModelRequest,
    EditModelResponseBody,
    EditModelResponse,
    GetBastionHostCertificationRequest,
    GetBastionHostCertificationResponseBody,
    GetBastionHostCertificationResponse,
    IterateModelRequest,
    IterateModelResponseBody,
    IterateModelResponse,
    OfflineModelRequest,
    OfflineModelResponseBody,
    OfflineModelResponse,
    OnlineModelRequest,
    OnlineModelResponseBody,
    OnlineModelResponse,
    ParseExpressionParametersRequest,
    ParseExpressionParametersResponseBody,
    ParseExpressionParametersResponse,
    PrepublishModelRequest,
    PrepublishModelResponseBody,
    PrepublishModelResponse,
    RequestModelFileSyncRequest,
    RequestModelFileSyncResponseBody,
    RequestModelFileSyncResponse,
    RollbackModelRequest,
    RollbackModelResponseBody,
    RollbackModelResponse,
    TestModelRequest,
    TestModelResponseBody,
    TestModelResponse,
    TestPreModelRequest,
    TestPreModelResponseBody,
    TestPreModelResponse,
    TestProcessExpressionRequest,
    TestProcessExpressionResponseBody,
    TestProcessExpressionResponse,
    UpdateModuleBasicInfoRequest,
    UpdateModuleBasicInfoResponseBody,
    UpdateModuleBasicInfoResponse,
    ValidateModelFileRequest,
    ValidateModelFileResponseBody,
    ValidateModelFileResponse,
    ValidateTestFileRequest,
    ValidateTestFileResponseBody,
    ValidateTestFileResponse,
    CreateModelingProjectResponseBodyResultObject,
    DescribeCustomerModuleBasicInfoResponseBodyResultObject,
    DescribeCustomerModuleMetaInfoResponseBodyResultObjectFeatureList,
    DescribeCustomerModuleMetaInfoResponseBodyResultObject,
    DescribeCustomerModuleOutputInfoResponseBodyResultObject,
    DescribeFeatureOptionResponseBodyResultObject,
    DescribeFeatureTemplateListResponseBodyResultObject,
    DescribeModelFeatureResponseBodyResultObject,
    DescribeModelOssTokenResponseBodyResultObject,
    DescribeModelingProjectDetailResponseBodyResultObjectPocTasks,
    DescribeModelingProjectDetailResponseBodyResultObjectSyncedFilesFiles,
    DescribeModelingProjectDetailResponseBodyResultObjectSyncedFiles,
    DescribeModelingProjectDetailResponseBodyResultObject,
    DescribeModelingProjectListResponseBodyResultObject,
    DescribePocTaskListResponseBodyResultObject,
    DescribeSafRmmpOrderResponseBodyResultObject,
    DescribeServiceAndSceneResponseBodyResultObject,
    DescribeUserModelListResponseBodyResultObject,
    ParseExpressionParametersResponseBodyResultObject,
    TestModelResponseBodyResultObjectTestResult,
    TestModelResponseBodyResultObject,
    TestProcessExpressionResponseBodyResultObject,
    ValidateModelFileResponseBodyResultObject,
    ValidateTestFileResponseBodyResultObject
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AssociatePocTaskRequest(DaraModel):
    def __init__(
        self,
        project_id: int = None,
        task_id: int = None,
    ):
        # Project ID
        self.project_id = project_id
        # Retrospective task ID.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.project_id is not None:
            result['ProjectId'] = self.project_id

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ProjectId') is not None:
            self.project_id = m.get('ProjectId')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeCustomerModuleBasicInfoResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        http_status_code: int = None,
        message: str = None,
        request_id: str = None,
        result_object: main_models.DescribeCustomerModuleBasicInfoResponseBodyResultObject = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # HTTP status code.
        self.http_status_code = http_status_code
        # Return message.
        self.message = message
        # Request ID
        self.request_id = request_id
        # Returned result.
        self.result_object = result_object
        # Indicates whether the application configuration information was successfully retrieved. Possible values: true: Success; false: Failure.
        self.success = success

    def validate(self):
        if self.result_object:
            self.result_object.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object.to_map()

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            temp_model = main_models.DescribeCustomerModuleBasicInfoResponseBodyResultObject()
            self.result_object = temp_model.from_map(m.get('ResultObject'))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCustomerModuleBasicInfoResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        customer_module_name: str = None,
        description: str = None,
        inner_module_name: str = None,
        module_type: str = None,
        store_path: str = None,
    ):
        # Customer model name.
        self.customer_module_name = customer_module_name
        # Remarks.
        self.description = description
        # Model identifier.
        self.inner_module_name = inner_module_name
        # Module type.
        self.module_type = module_type
        # Test address.
        self.store_path = store_path

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.customer_module_name is not None:
            result['CustomerModuleName'] = self.customer_module_name

        if self.description is not None:
            result['Description'] = self.description

        if self.inner_module_name is not None:
            result['InnerModuleName'] = self.inner_module_name

        if self.module_type is not None:
            result['ModuleType'] = self.module_type

        if self.store_path is not None:
            result['StorePath'] = self.store_path

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomerModuleName') is not None:
            self.customer_module_name = m.get('CustomerModuleName')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('InnerModuleName') is not None:
            self.inner_module_name = m.get('InnerModuleName')

        if m.get('ModuleType') is not None:
            self.module_type = m.get('ModuleType')

        if m.get('StorePath') is not None:
            self.store_path = m.get('StorePath')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeModelingProjectListRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        page_size: int = None,
        status: str = None,
    ):
        # Current page.
        self.current_page = current_page
        # Pagination parameter: number of items per page, with a default value of 10.
        self.page_size = page_size
        # Project status.
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ParseExpressionParametersRequest(DaraModel):
    def __init__(
        self,
        expression: str = None,
    ):
        # Expression.
        self.expression = expression

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.expression is not None:
            result['Expression'] = self.expression

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Expression') is not None:
            self.expression = m.get('Expression')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateModuleBasicInfoRequest(DaraModel):
    def __init__(
        self,
        customer_module_id: int = None,
        customer_module_name: str = None,
        description: str = None,
        module_type: str = None,
        store_path: str = None,
    ):
        # Customer model ID
        self.customer_module_id = customer_module_id
        # Model name.
        self.customer_module_name = customer_module_name
        # Description.
        self.description = description
        # Module type.
        self.module_type = module_type
        # Test address.
        self.store_path = store_path

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.customer_module_id is not None:
            result['CustomerModuleId'] = self.customer_module_id

        if self.customer_module_name is not None:
            result['CustomerModuleName'] = self.customer_module_name

        if self.description is not None:
            result['Description'] = self.description

        if self.module_type is not None:
            result['ModuleType'] = self.module_type

        if self.store_path is not None:
            result['StorePath'] = self.store_path

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomerModuleId') is not None:
            self.customer_module_id = m.get('CustomerModuleId')

        if m.get('CustomerModuleName') is not None:
            self.customer_module_name = m.get('CustomerModuleName')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('ModuleType') is not None:
            self.module_type = m.get('ModuleType')

        if m.get('StorePath') is not None:
            self.store_path = m.get('StorePath')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeUserModelListRequest(DaraModel):
    def __init__(
        self,
        auth_type: str = None,
        current_page: str = None,
        name: str = None,
        page_size: str = None,
    ):
        # Authorization type.
        self.auth_type = auth_type
        # Current page number.
        self.current_page = current_page
        # Model name.
        self.name = name
        # Pagination parameter: number of items per page, default value 10.
        self.page_size = page_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_type is not None:
            result['AuthType'] = self.auth_type

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.name is not None:
            result['Name'] = self.name

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AuthType') is not None:
            self.auth_type = m.get('AuthType')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateModelingProjectRequest(DaraModel):
    def __init__(
        self,
        instance_spec: str = None,
        project_name: str = None,
        remark: str = None,
    ):
        # Instance specification.
        # 
        # This parameter is required.
        self.instance_spec = instance_spec
        # Project name
        # 
        # This parameter is required.
        self.project_name = project_name
        # Remark.
        self.remark = remark

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_spec is not None:
            result['InstanceSpec'] = self.instance_spec

        if self.project_name is not None:
            result['ProjectName'] = self.project_name

        if self.remark is not None:
            result['Remark'] = self.remark

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceSpec') is not None:
            self.instance_spec = m.get('InstanceSpec')

        if m.get('ProjectName') is not None:
            self.project_name = m.get('ProjectName')

        if m.get('Remark') is not None:
            self.remark = m.get('Remark')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class IterateModelResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        http_status_code: int = None,
        request_id: str = None,
        result_object: str = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # HTTP status code.
        self.http_status_code = http_status_code
        # Request ID.
        self.request_id = request_id
        # Result object.
        self.result_object = result_object
        # Whether the call was successful.
        # 
        # - **true**: Call succeeded.
        # - **false**: Call failed.
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            self.result_object = m.get('ResultObject')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeCustomerModuleOutputInfoResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        http_status_code: int = None,
        message: str = None,
        request_id: str = None,
        result_object: main_models.DescribeCustomerModuleOutputInfoResponseBodyResultObject = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # HTTP status code.
        self.http_status_code = http_status_code
        # Return message.
        self.message = message
        # Request ID
        self.request_id = request_id
        # Returned result.
        self.result_object = result_object
        # Indicates whether the request was successful, with possible values as follows:
        # - true, indicating the request was successful
        # - false, indicating the request failed
        self.success = success

    def validate(self):
        if self.result_object:
            self.result_object.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object.to_map()

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            temp_model = main_models.DescribeCustomerModuleOutputInfoResponseBodyResultObject()
            self.result_object = temp_model.from_map(m.get('ResultObject'))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCustomerModuleOutputInfoResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        final_score_format: str = None,
        process_expression: str = None,
        test_file: str = None,
    ):
        # Number of decimal places for the output.
        self.final_score_format = final_score_format
        # Score processing logic.
        self.process_expression = process_expression
        # Test file.
        self.test_file = test_file

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.final_score_format is not None:
            result['FinalScoreFormat'] = self.final_score_format

        if self.process_expression is not None:
            result['ProcessExpression'] = self.process_expression

        if self.test_file is not None:
            result['TestFile'] = self.test_file

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FinalScoreFormat') is not None:
            self.final_score_format = m.get('FinalScoreFormat')

        if m.get('ProcessExpression') is not None:
            self.process_expression = m.get('ProcessExpression')

        if m.get('TestFile') is not None:
            self.test_file = m.get('TestFile')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeCustomerModuleOutputInfoResponse(DaraModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: main_models.DescribeCustomerModuleOutputInfoResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.headers is not None:
            result['headers'] = self.headers

        if self.status_code is not None:
            result['statusCode'] = self.status_code

        if self.body is not None:
            result['body'] = self.body.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')

        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')

        if m.get('body') is not None:
            temp_model = main_models.DescribeCustomerModuleOutputInfoResponseBody()
            self.body = temp_model.from_map(m.get('body'))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class DescribeUserModelListResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        current_page: int = None,
        http_status_code: int = None,
        page_size: int = None,
        request_id: str = None,
        result_object: List[main_models.DescribeUserModelListResponseBodyResultObject] = None,
        success: bool = None,
        total_item: int = None,
        total_page: int = None,
    ):
        # `code`
        self.code = code
        # Current page.
        self.current_page = current_page
        # HTTP status code.
        self.http_status_code = http_status_code
        # Pagination parameter: number of items per page, default value is 10.
        self.page_size = page_size
        # Request ID.
        self.request_id = request_id
        # Return result.
        self.result_object = result_object
        # Indicates whether the request was successful, with values as follows:
        # - true, request succeeded
        # - false, request failed
        self.success = success
        # Total number of records.
        self.total_item = total_item
        # Total number of pages.
        self.total_page = total_page

    def validate(self):
        if self.result_object:
            for v1 in self.result_object:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        result['ResultObject'] = []
        if self.result_object is not None:
            for k1 in self.result_object:
                result['ResultObject'].append(k1.to_map() if k1 else None)

        if self.success is not None:
            result['Success'] = self.success

        if self.total_item is not None:
            result['TotalItem'] = self.total_item

        if self.total_page is not None:
            result['TotalPage'] = self.total_page

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        self.result_object = []
        if m.get('ResultObject') is not None:
            for k1 in m.get('ResultObject'):
                temp_model = main_models.DescribeUserModelListResponseBodyResultObject()
                self.result_object.append(temp_model.from_map(k1))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('TotalItem') is not None:
            self.total_item = m.get('TotalItem')

        if m.get('TotalPage') is not None:
            self.total_page = m.get('TotalPage')

        return self

class DescribeUserModelListResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        auth_type: str = None,
        customer_module_name: str = None,
        description: str = None,
        feature_template: str = None,
        gmt_modified: int = None,
        id: int = None,
        inner_define_status: str = None,
        inner_module_name: str = None,
        is_allow_iterate: bool = None,
        is_allow_rollback: bool = None,
        iteration_version: int = None,
        root_module_id: int = None,
    ):
        # Authorization type.
        self.auth_type = auth_type
        # Model name.
        self.customer_module_name = customer_module_name
        # Remarks.
        self.description = description
        # Associated features.
        self.feature_template = feature_template
        # Modification time.
        self.gmt_modified = gmt_modified
        # Primary key ID of the model.
        self.id = id
        # Publication status.
        self.inner_define_status = inner_define_status
        # Model identifier.
        self.inner_module_name = inner_module_name
        # Whether iteration is allowed.
        self.is_allow_iterate = is_allow_iterate
        # Whether rollback is allowed.
        self.is_allow_rollback = is_allow_rollback
        # Iteration version.
        self.iteration_version = iteration_version
        # Root model ID.
        self.root_module_id = root_module_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auth_type is not None:
            result['AuthType'] = self.auth_type

        if self.customer_module_name is not None:
            result['CustomerModuleName'] = self.customer_module_name

        if self.description is not None:
            result['Description'] = self.description

        if self.feature_template is not None:
            result['FeatureTemplate'] = self.feature_template

        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified

        if self.id is not None:
            result['Id'] = self.id

        if self.inner_define_status is not None:
            result['InnerDefineStatus'] = self.inner_define_status

        if self.inner_module_name is not None:
            result['InnerModuleName'] = self.inner_module_name

        if self.is_allow_iterate is not None:
            result['IsAllowIterate'] = self.is_allow_iterate

        if self.is_allow_rollback is not None:
            result['IsAllowRollback'] = self.is_allow_rollback

        if self.iteration_version is not None:
            result['IterationVersion'] = self.iteration_version

        if self.root_module_id is not None:
            result['RootModuleId'] = self.root_module_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AuthType') is not None:
            self.auth_type = m.get('AuthType')

        if m.get('CustomerModuleName') is not None:
            self.customer_module_name = m.get('CustomerModuleName')

        if m.get('Description') is not None:
            self.description = m.get('Description')

        if m.get('FeatureTemplate') is not None:
            self.feature_template = m.get('FeatureTemplate')

        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InnerDefineStatus') is not None:
            self.inner_define_status = m.get('InnerDefineStatus')

        if m.get('InnerModuleName') is not None:
            self.inner_module_name = m.get('InnerModuleName')

        if m.get('IsAllowIterate') is not None:
            self.is_allow_iterate = m.get('IsAllowIterate')

        if m.get('IsAllowRollback') is not None:
            self.is_allow_rollback = m.get('IsAllowRollback')

        if m.get('IterationVersion') is not None:
            self.iteration_version = m.get('IterationVersion')

        if m.get('RootModuleId') is not None:
            self.root_module_id = m.get('RootModuleId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_safconsole20250521 import models as main_models
from darabonba.model import DaraModel

class TestModelResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        http_status_code: int = None,
        request_id: str = None,
        result_object: main_models.TestModelResponseBodyResultObject = None,
        success: bool = None,
    ):
        # Status code. A return value of 200 indicates success.
        self.code = code
        # HTTP status code.
        self.http_status_code = http_status_code
        # Request ID.
        self.request_id = request_id
        # Return result.
        self.result_object = result_object
        # Indicates whether the call was successful.
        # 
        # - **true**: Call succeeded.
        # - **false**: Call failed.
        self.success = success

    def validate(self):
        if self.result_object:
            self.result_object.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.result_object is not None:
            result['ResultObject'] = self.result_object.to_map()

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResultObject') is not None:
            temp_model = main_models.TestModelResponseBodyResultObject()
            self.result_object = temp_model.from_map(m.get('ResultObject'))

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class TestModelResponseBodyResultObject(DaraModel):
    def __init__(
        self,
        consistency_count: int = None,
        consistency_rate: float = None,
        test_result: List[main_models.TestModelResponseBodyResultObjectTestResult] = None,
        total: int = None,
    ):
        # Number of consistencies.
        self.consistency_count = consistency_count
        # Consistency rate.
        self.consistency_rate = consistency_rate
        # Test results.
        self.test_result = test_result
        # Total number.
        self.total = total

    def validate(self):
        if self.test_result:
            for v1 in self.test_result:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.consistency_count is not None:
            result['ConsistencyCount'] = self.consistency_count

        if self.consistency_rate is not None:
            result['ConsistencyRate'] = self.consistency_rate

        result['TestResult'] = []
        if self.test_result is not None:
            for k1 in self.test_result:
                result['TestResult'].append(k1.to_map() if k1 else None)

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsistencyCount') is not None:
            self.consistency_count = m.get('ConsistencyCount')

        if m.get('ConsistencyRate') is not None:
            self.consistency_rate = m.get('ConsistencyRate')

        self.test_result = []
        if m.get('TestResult') is not None:
            for k1 in m.get('TestResult'):
                temp_model = main_models.TestModelResponseBodyResultObjectTestResult()
                self.test_result.append(temp_model.from_map(k1))

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class TestModelResponseBodyResultObjectTestResult(DaraModel):
    def __init__(
        self,
        actual_result: str = None,
        consistency: bool = None,
        test_result: str = None,
        train_result: str = None,
    ):
        # Actual output.
        self.actual_result = actual_result
        # Whether it is consistent.
        self.consistency = consistency
        # Test output.
        self.test_result = test_result
        # Training output.
        self.train_result = train_result

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.actual_result is not None:
            result['ActualResult'] = self.actual_result

        if self.consistency is not None:
            result['Consistency'] = self.consistency

        if self.test_result is not None:
            result['TestResult'] = self.test_result

        if self.train_result is not None:
            result['TrainResult'] = self.train_result

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ActualResult') is not None:
            self.actual_result = m.get('ActualResult')

        if m.get('Consistency') is not None:
            self.consistency = m.get('Consistency')

        if m.get('TestResult') is not None:
            self.test_result = m.get('TestResult')

        if m.get('TrainResult') is not None:
            self.train_result = m.get('TrainResult')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict

from alibabacloud_safconsole20250521 import models as main_models
from alibabacloud_tea_openapi import utils_models as open_api_util_models
from alibabacloud_tea_openapi.client import Client as OpenApiClient
from alibabacloud_tea_openapi.utils import Utils
from darabonba.core import DaraCore as DaraCore
from darabonba.runtime import RuntimeOptions

"""
"""
class Client(OpenApiClient):

    def __init__(
        self,
        config: open_api_util_models.Config,
    ):
        super().__init__(config)
        self._endpoint_rule = ''
        self.check_config(config)
        self._endpoint = self.get_endpoint('safconsole', self._region_id, self._endpoint_rule, self._network, self._suffix, self._endpoint_map, self._endpoint)

    def get_endpoint(
        self,
        product_id: str,
        region_id: str,
        endpoint_rule: str,
        network: str,
        suffix: str,
        endpoint_map: Dict[str, str],
        endpoint: str,
    ) -> str:
        if not DaraCore.is_null(endpoint):
            return endpoint
        if not DaraCore.is_null(endpoint_map) and not DaraCore.is_null(endpoint_map.get(region_id)):
            return endpoint_map.get(region_id)
        return Utils.get_endpoint_rules(product_id, region_id, endpoint_rule, network, suffix)

    def apply_bastion_account_with_options(
        self,
        request: main_models.ApplyBastionAccountRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ApplyBastionAccountResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.mobile):
            query['Mobile'] = request.mobile
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ApplyBastionAccount',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ApplyBastionAccountResponse(),
            self.call_api(params, req, runtime)
        )

    async def apply_bastion_account_with_options_async(
        self,
        request: main_models.ApplyBastionAccountRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ApplyBastionAccountResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.mobile):
            query['Mobile'] = request.mobile
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ApplyBastionAccount',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ApplyBastionAccountResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def apply_bastion_account(
        self,
        request: main_models.ApplyBastionAccountRequest,
    ) -> main_models.ApplyBastionAccountResponse:
        runtime = RuntimeOptions()
        return self.apply_bastion_account_with_options(request, runtime)

    async def apply_bastion_account_async(
        self,
        request: main_models.ApplyBastionAccountRequest,
    ) -> main_models.ApplyBastionAccountResponse:
        runtime = RuntimeOptions()
        return await self.apply_bastion_account_with_options_async(request, runtime)

    def associate_poc_task_with_options(
        self,
        request: main_models.AssociatePocTaskRequest,
        runtime: RuntimeOptions,
    ) -> main_models.AssociatePocTaskResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        if not DaraCore.is_null(request.task_id):
            query['TaskId'] = request.task_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'AssociatePocTask',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.AssociatePocTaskResponse(),
            self.call_api(params, req, runtime)
        )

    async def associate_poc_task_with_options_async(
        self,
        request: main_models.AssociatePocTaskRequest,
        runtime: RuntimeOptions,
    ) -> main_models.AssociatePocTaskResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        if not DaraCore.is_null(request.task_id):
            query['TaskId'] = request.task_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'AssociatePocTask',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.AssociatePocTaskResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def associate_poc_task(
        self,
        request: main_models.AssociatePocTaskRequest,
    ) -> main_models.AssociatePocTaskResponse:
        runtime = RuntimeOptions()
        return self.associate_poc_task_with_options(request, runtime)

    async def associate_poc_task_async(
        self,
        request: main_models.AssociatePocTaskRequest,
    ) -> main_models.AssociatePocTaskResponse:
        runtime = RuntimeOptions()
        return await self.associate_poc_task_with_options_async(request, runtime)

    def complete_modeling_project_with_options(
        self,
        request: main_models.CompleteModelingProjectRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CompleteModelingProjectResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CompleteModelingProject',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CompleteModelingProjectResponse(),
            self.call_api(params, req, runtime)
        )

    async def complete_modeling_project_with_options_async(
        self,
        request: main_models.CompleteModelingProjectRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CompleteModelingProjectResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CompleteModelingProject',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CompleteModelingProjectResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def complete_modeling_project(
        self,
        request: main_models.CompleteModelingProjectRequest,
    ) -> main_models.CompleteModelingProjectResponse:
        runtime = RuntimeOptions()
        return self.complete_modeling_project_with_options(request, runtime)

    async def complete_modeling_project_async(
        self,
        request: main_models.CompleteModelingProjectRequest,
    ) -> main_models.CompleteModelingProjectResponse:
        runtime = RuntimeOptions()
        return await self.complete_modeling_project_with_options_async(request, runtime)

    def create_customer_module_basic_info_with_options(
        self,
        request: main_models.CreateCustomerModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_name):
            query['CustomerModuleName'] = request.customer_module_name
        if not DaraCore.is_null(request.description):
            query['Description'] = request.description
        if not DaraCore.is_null(request.module_type):
            query['ModuleType'] = request.module_type
        if not DaraCore.is_null(request.store_path):
            query['StorePath'] = request.store_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleBasicInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_customer_module_basic_info_with_options_async(
        self,
        request: main_models.CreateCustomerModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_name):
            query['CustomerModuleName'] = request.customer_module_name
        if not DaraCore.is_null(request.description):
            query['Description'] = request.description
        if not DaraCore.is_null(request.module_type):
            query['ModuleType'] = request.module_type
        if not DaraCore.is_null(request.store_path):
            query['StorePath'] = request.store_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleBasicInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_customer_module_basic_info(
        self,
        request: main_models.CreateCustomerModuleBasicInfoRequest,
    ) -> main_models.CreateCustomerModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return self.create_customer_module_basic_info_with_options(request, runtime)

    async def create_customer_module_basic_info_async(
        self,
        request: main_models.CreateCustomerModuleBasicInfoRequest,
    ) -> main_models.CreateCustomerModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return await self.create_customer_module_basic_info_with_options_async(request, runtime)

    def create_customer_module_meta_info_with_options(
        self,
        request: main_models.CreateCustomerModuleMetaInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleMetaInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.feature_string):
            query['FeatureString'] = request.feature_string
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleMetaInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleMetaInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_customer_module_meta_info_with_options_async(
        self,
        request: main_models.CreateCustomerModuleMetaInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleMetaInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.feature_string):
            query['FeatureString'] = request.feature_string
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleMetaInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleMetaInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_customer_module_meta_info(
        self,
        request: main_models.CreateCustomerModuleMetaInfoRequest,
    ) -> main_models.CreateCustomerModuleMetaInfoResponse:
        runtime = RuntimeOptions()
        return self.create_customer_module_meta_info_with_options(request, runtime)

    async def create_customer_module_meta_info_async(
        self,
        request: main_models.CreateCustomerModuleMetaInfoRequest,
    ) -> main_models.CreateCustomerModuleMetaInfoResponse:
        runtime = RuntimeOptions()
        return await self.create_customer_module_meta_info_with_options_async(request, runtime)

    def create_customer_module_output_info_with_options(
        self,
        request: main_models.CreateCustomerModuleOutputInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleOutputInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.final_score_format):
            query['FinalScoreFormat'] = request.final_score_format
        if not DaraCore.is_null(request.process_expression):
            query['ProcessExpression'] = request.process_expression
        if not DaraCore.is_null(request.test_file_url):
            query['TestFileUrl'] = request.test_file_url
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleOutputInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleOutputInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_customer_module_output_info_with_options_async(
        self,
        request: main_models.CreateCustomerModuleOutputInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateCustomerModuleOutputInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.final_score_format):
            query['FinalScoreFormat'] = request.final_score_format
        if not DaraCore.is_null(request.process_expression):
            query['ProcessExpression'] = request.process_expression
        if not DaraCore.is_null(request.test_file_url):
            query['TestFileUrl'] = request.test_file_url
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateCustomerModuleOutputInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateCustomerModuleOutputInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_customer_module_output_info(
        self,
        request: main_models.CreateCustomerModuleOutputInfoRequest,
    ) -> main_models.CreateCustomerModuleOutputInfoResponse:
        runtime = RuntimeOptions()
        return self.create_customer_module_output_info_with_options(request, runtime)

    async def create_customer_module_output_info_async(
        self,
        request: main_models.CreateCustomerModuleOutputInfoRequest,
    ) -> main_models.CreateCustomerModuleOutputInfoResponse:
        runtime = RuntimeOptions()
        return await self.create_customer_module_output_info_with_options_async(request, runtime)

    def create_modeling_project_with_options(
        self,
        request: main_models.CreateModelingProjectRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateModelingProjectResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_spec):
            query['InstanceSpec'] = request.instance_spec
        if not DaraCore.is_null(request.project_name):
            query['ProjectName'] = request.project_name
        if not DaraCore.is_null(request.remark):
            query['Remark'] = request.remark
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateModelingProject',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateModelingProjectResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_modeling_project_with_options_async(
        self,
        request: main_models.CreateModelingProjectRequest,
        runtime: RuntimeOptions,
    ) -> main_models.CreateModelingProjectResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_spec):
            query['InstanceSpec'] = request.instance_spec
        if not DaraCore.is_null(request.project_name):
            query['ProjectName'] = request.project_name
        if not DaraCore.is_null(request.remark):
            query['Remark'] = request.remark
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'CreateModelingProject',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateModelingProjectResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_modeling_project(
        self,
        request: main_models.CreateModelingProjectRequest,
    ) -> main_models.CreateModelingProjectResponse:
        runtime = RuntimeOptions()
        return self.create_modeling_project_with_options(request, runtime)

    async def create_modeling_project_async(
        self,
        request: main_models.CreateModelingProjectRequest,
    ) -> main_models.CreateModelingProjectResponse:
        runtime = RuntimeOptions()
        return await self.create_modeling_project_with_options_async(request, runtime)

    def delete_model_with_options(
        self,
        request: main_models.DeleteModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DeleteModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeleteModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeleteModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def delete_model_with_options_async(
        self,
        request: main_models.DeleteModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DeleteModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeleteModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeleteModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def delete_model(
        self,
        request: main_models.DeleteModelRequest,
    ) -> main_models.DeleteModelResponse:
        runtime = RuntimeOptions()
        return self.delete_model_with_options(request, runtime)

    async def delete_model_async(
        self,
        request: main_models.DeleteModelRequest,
    ) -> main_models.DeleteModelResponse:
        runtime = RuntimeOptions()
        return await self.delete_model_with_options_async(request, runtime)

    def deploy_model_file_with_options(
        self,
        request: main_models.DeployModelFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DeployModelFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.group_id):
            query['GroupId'] = request.group_id
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeployModelFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeployModelFileResponse(),
            self.call_api(params, req, runtime)
        )

    async def deploy_model_file_with_options_async(
        self,
        request: main_models.DeployModelFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DeployModelFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.group_id):
            query['GroupId'] = request.group_id
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeployModelFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeployModelFileResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def deploy_model_file(
        self,
        request: main_models.DeployModelFileRequest,
    ) -> main_models.DeployModelFileResponse:
        runtime = RuntimeOptions()
        return self.deploy_model_file_with_options(request, runtime)

    async def deploy_model_file_async(
        self,
        request: main_models.DeployModelFileRequest,
    ) -> main_models.DeployModelFileResponse:
        runtime = RuntimeOptions()
        return await self.deploy_model_file_with_options_async(request, runtime)

    def describe_customer_module_basic_info_with_options(
        self,
        request: main_models.DescribeCustomerModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleBasicInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_customer_module_basic_info_with_options_async(
        self,
        request: main_models.DescribeCustomerModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleBasicInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_customer_module_basic_info(
        self,
        request: main_models.DescribeCustomerModuleBasicInfoRequest,
    ) -> main_models.DescribeCustomerModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return self.describe_customer_module_basic_info_with_options(request, runtime)

    async def describe_customer_module_basic_info_async(
        self,
        request: main_models.DescribeCustomerModuleBasicInfoRequest,
    ) -> main_models.DescribeCustomerModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return await self.describe_customer_module_basic_info_with_options_async(request, runtime)

    def describe_customer_module_meta_info_with_options(
        self,
        request: main_models.DescribeCustomerModuleMetaInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleMetaInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleMetaInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleMetaInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_customer_module_meta_info_with_options_async(
        self,
        request: main_models.DescribeCustomerModuleMetaInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleMetaInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleMetaInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleMetaInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_customer_module_meta_info(
        self,
        request: main_models.DescribeCustomerModuleMetaInfoRequest,
    ) -> main_models.DescribeCustomerModuleMetaInfoResponse:
        runtime = RuntimeOptions()
        return self.describe_customer_module_meta_info_with_options(request, runtime)

    async def describe_customer_module_meta_info_async(
        self,
        request: main_models.DescribeCustomerModuleMetaInfoRequest,
    ) -> main_models.DescribeCustomerModuleMetaInfoResponse:
        runtime = RuntimeOptions()
        return await self.describe_customer_module_meta_info_with_options_async(request, runtime)

    def describe_customer_module_output_info_with_options(
        self,
        request: main_models.DescribeCustomerModuleOutputInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleOutputInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleOutputInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleOutputInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_customer_module_output_info_with_options_async(
        self,
        request: main_models.DescribeCustomerModuleOutputInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeCustomerModuleOutputInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeCustomerModuleOutputInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeCustomerModuleOutputInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_customer_module_output_info(
        self,
        request: main_models.DescribeCustomerModuleOutputInfoRequest,
    ) -> main_models.DescribeCustomerModuleOutputInfoResponse:
        runtime = RuntimeOptions()
        return self.describe_customer_module_output_info_with_options(request, runtime)

    async def describe_customer_module_output_info_async(
        self,
        request: main_models.DescribeCustomerModuleOutputInfoRequest,
    ) -> main_models.DescribeCustomerModuleOutputInfoResponse:
        runtime = RuntimeOptions()
        return await self.describe_customer_module_output_info_with_options_async(request, runtime)

    def describe_feature_option_with_options(
        self,
        request: main_models.DescribeFeatureOptionRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFeatureOptionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeFeatureOption',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFeatureOptionResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_feature_option_with_options_async(
        self,
        request: main_models.DescribeFeatureOptionRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFeatureOptionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeFeatureOption',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFeatureOptionResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_feature_option(
        self,
        request: main_models.DescribeFeatureOptionRequest,
    ) -> main_models.DescribeFeatureOptionResponse:
        runtime = RuntimeOptions()
        return self.describe_feature_option_with_options(request, runtime)

    async def describe_feature_option_async(
        self,
        request: main_models.DescribeFeatureOptionRequest,
    ) -> main_models.DescribeFeatureOptionResponse:
        runtime = RuntimeOptions()
        return await self.describe_feature_option_with_options_async(request, runtime)

    def describe_feature_template_list_with_options(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFeatureTemplateListResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeFeatureTemplateList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFeatureTemplateListResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_feature_template_list_with_options_async(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFeatureTemplateListResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeFeatureTemplateList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFeatureTemplateListResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_feature_template_list(self) -> main_models.DescribeFeatureTemplateListResponse:
        runtime = RuntimeOptions()
        return self.describe_feature_template_list_with_options(runtime)

    async def describe_feature_template_list_async(self) -> main_models.DescribeFeatureTemplateListResponse:
        runtime = RuntimeOptions()
        return await self.describe_feature_template_list_with_options_async(runtime)

    def describe_file_download_url_with_options(
        self,
        request: main_models.DescribeFileDownloadUrlRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFileDownloadUrlResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.file_id):
            query['FileId'] = request.file_id
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeFileDownloadUrl',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFileDownloadUrlResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_file_download_url_with_options_async(
        self,
        request: main_models.DescribeFileDownloadUrlRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeFileDownloadUrlResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.file_id):
            query['FileId'] = request.file_id
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeFileDownloadUrl',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeFileDownloadUrlResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_file_download_url(
        self,
        request: main_models.DescribeFileDownloadUrlRequest,
    ) -> main_models.DescribeFileDownloadUrlResponse:
        runtime = RuntimeOptions()
        return self.describe_file_download_url_with_options(request, runtime)

    async def describe_file_download_url_async(
        self,
        request: main_models.DescribeFileDownloadUrlRequest,
    ) -> main_models.DescribeFileDownloadUrlResponse:
        runtime = RuntimeOptions()
        return await self.describe_file_download_url_with_options_async(request, runtime)

    def describe_model_feature_with_options(
        self,
        request: main_models.DescribeModelFeatureRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelFeatureResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelFeature',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelFeatureResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_model_feature_with_options_async(
        self,
        request: main_models.DescribeModelFeatureRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelFeatureResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.feature_template):
            query['FeatureTemplate'] = request.feature_template
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelFeature',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelFeatureResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_model_feature(
        self,
        request: main_models.DescribeModelFeatureRequest,
    ) -> main_models.DescribeModelFeatureResponse:
        runtime = RuntimeOptions()
        return self.describe_model_feature_with_options(request, runtime)

    async def describe_model_feature_async(
        self,
        request: main_models.DescribeModelFeatureRequest,
    ) -> main_models.DescribeModelFeatureResponse:
        runtime = RuntimeOptions()
        return await self.describe_model_feature_with_options_async(request, runtime)

    def describe_model_oss_token_with_options(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelOssTokenResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeModelOssToken',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelOssTokenResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_model_oss_token_with_options_async(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelOssTokenResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeModelOssToken',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelOssTokenResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_model_oss_token(self) -> main_models.DescribeModelOssTokenResponse:
        runtime = RuntimeOptions()
        return self.describe_model_oss_token_with_options(runtime)

    async def describe_model_oss_token_async(self) -> main_models.DescribeModelOssTokenResponse:
        runtime = RuntimeOptions()
        return await self.describe_model_oss_token_with_options_async(runtime)

    def describe_modeling_project_detail_with_options(
        self,
        request: main_models.DescribeModelingProjectDetailRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelingProjectDetailResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelingProjectDetail',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelingProjectDetailResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_modeling_project_detail_with_options_async(
        self,
        request: main_models.DescribeModelingProjectDetailRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelingProjectDetailResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelingProjectDetail',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelingProjectDetailResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_modeling_project_detail(
        self,
        request: main_models.DescribeModelingProjectDetailRequest,
    ) -> main_models.DescribeModelingProjectDetailResponse:
        runtime = RuntimeOptions()
        return self.describe_modeling_project_detail_with_options(request, runtime)

    async def describe_modeling_project_detail_async(
        self,
        request: main_models.DescribeModelingProjectDetailRequest,
    ) -> main_models.DescribeModelingProjectDetailResponse:
        runtime = RuntimeOptions()
        return await self.describe_modeling_project_detail_with_options_async(request, runtime)

    def describe_modeling_project_list_with_options(
        self,
        request: main_models.DescribeModelingProjectListRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelingProjectListResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.current_page):
            query['CurrentPage'] = request.current_page
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        if not DaraCore.is_null(request.status):
            query['Status'] = request.status
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelingProjectList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelingProjectListResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_modeling_project_list_with_options_async(
        self,
        request: main_models.DescribeModelingProjectListRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModelingProjectListResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.current_page):
            query['CurrentPage'] = request.current_page
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        if not DaraCore.is_null(request.status):
            query['Status'] = request.status
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModelingProjectList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModelingProjectListResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_modeling_project_list(
        self,
        request: main_models.DescribeModelingProjectListRequest,
    ) -> main_models.DescribeModelingProjectListResponse:
        runtime = RuntimeOptions()
        return self.describe_modeling_project_list_with_options(request, runtime)

    async def describe_modeling_project_list_async(
        self,
        request: main_models.DescribeModelingProjectListRequest,
    ) -> main_models.DescribeModelingProjectListResponse:
        runtime = RuntimeOptions()
        return await self.describe_modeling_project_list_with_options_async(request, runtime)

    def describe_module_service_exist_with_options(
        self,
        request: main_models.DescribeModuleServiceExistRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModuleServiceExistResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModuleServiceExist',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModuleServiceExistResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_module_service_exist_with_options_async(
        self,
        request: main_models.DescribeModuleServiceExistRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModuleServiceExistResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModuleServiceExist',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModuleServiceExistResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_module_service_exist(
        self,
        request: main_models.DescribeModuleServiceExistRequest,
    ) -> main_models.DescribeModuleServiceExistResponse:
        runtime = RuntimeOptions()
        return self.describe_module_service_exist_with_options(request, runtime)

    async def describe_module_service_exist_async(
        self,
        request: main_models.DescribeModuleServiceExistRequest,
    ) -> main_models.DescribeModuleServiceExistResponse:
        runtime = RuntimeOptions()
        return await self.describe_module_service_exist_with_options_async(request, runtime)

    def describe_module_status_with_options(
        self,
        request: main_models.DescribeModuleStatusRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModuleStatusResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModuleStatus',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModuleStatusResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_module_status_with_options_async(
        self,
        request: main_models.DescribeModuleStatusRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeModuleStatusResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeModuleStatus',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeModuleStatusResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_module_status(
        self,
        request: main_models.DescribeModuleStatusRequest,
    ) -> main_models.DescribeModuleStatusResponse:
        runtime = RuntimeOptions()
        return self.describe_module_status_with_options(request, runtime)

    async def describe_module_status_async(
        self,
        request: main_models.DescribeModuleStatusRequest,
    ) -> main_models.DescribeModuleStatusResponse:
        runtime = RuntimeOptions()
        return await self.describe_module_status_with_options_async(request, runtime)

    def describe_poc_task_list_with_options(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribePocTaskListResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribePocTaskList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribePocTaskListResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_poc_task_list_with_options_async(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribePocTaskListResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribePocTaskList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribePocTaskListResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_poc_task_list(self) -> main_models.DescribePocTaskListResponse:
        runtime = RuntimeOptions()
        return self.describe_poc_task_list_with_options(runtime)

    async def describe_poc_task_list_async(self) -> main_models.DescribePocTaskListResponse:
        runtime = RuntimeOptions()
        return await self.describe_poc_task_list_with_options_async(runtime)

    def describe_saf_rmmp_order_with_options(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeSafRmmpOrderResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeSafRmmpOrder',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeSafRmmpOrderResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_saf_rmmp_order_with_options_async(
        self,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeSafRmmpOrderResponse:
        req = open_api_util_models.OpenApiRequest()
        params = open_api_util_models.Params(
            action = 'DescribeSafRmmpOrder',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeSafRmmpOrderResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_saf_rmmp_order(self) -> main_models.DescribeSafRmmpOrderResponse:
        runtime = RuntimeOptions()
        return self.describe_saf_rmmp_order_with_options(runtime)

    async def describe_saf_rmmp_order_async(self) -> main_models.DescribeSafRmmpOrderResponse:
        runtime = RuntimeOptions()
        return await self.describe_saf_rmmp_order_with_options_async(runtime)

    def describe_service_and_scene_with_options(
        self,
        request: main_models.DescribeServiceAndSceneRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeServiceAndSceneResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeServiceAndScene',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeServiceAndSceneResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_service_and_scene_with_options_async(
        self,
        request: main_models.DescribeServiceAndSceneRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeServiceAndSceneResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeServiceAndScene',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeServiceAndSceneResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_service_and_scene(
        self,
        request: main_models.DescribeServiceAndSceneRequest,
    ) -> main_models.DescribeServiceAndSceneResponse:
        runtime = RuntimeOptions()
        return self.describe_service_and_scene_with_options(request, runtime)

    async def describe_service_and_scene_async(
        self,
        request: main_models.DescribeServiceAndSceneRequest,
    ) -> main_models.DescribeServiceAndSceneResponse:
        runtime = RuntimeOptions()
        return await self.describe_service_and_scene_with_options_async(request, runtime)

    def describe_user_model_list_with_options(
        self,
        request: main_models.DescribeUserModelListRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeUserModelListResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.current_page):
            query['CurrentPage'] = request.current_page
        if not DaraCore.is_null(request.name):
            query['Name'] = request.name
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeUserModelList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeUserModelListResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_user_model_list_with_options_async(
        self,
        request: main_models.DescribeUserModelListRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DescribeUserModelListResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auth_type):
            query['AuthType'] = request.auth_type
        if not DaraCore.is_null(request.current_page):
            query['CurrentPage'] = request.current_page
        if not DaraCore.is_null(request.name):
            query['Name'] = request.name
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeUserModelList',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeUserModelListResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_user_model_list(
        self,
        request: main_models.DescribeUserModelListRequest,
    ) -> main_models.DescribeUserModelListResponse:
        runtime = RuntimeOptions()
        return self.describe_user_model_list_with_options(request, runtime)

    async def describe_user_model_list_async(
        self,
        request: main_models.DescribeUserModelListRequest,
    ) -> main_models.DescribeUserModelListResponse:
        runtime = RuntimeOptions()
        return await self.describe_user_model_list_with_options_async(request, runtime)

    def duplicate_model_with_options(
        self,
        request: main_models.DuplicateModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DuplicateModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DuplicateModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DuplicateModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def duplicate_model_with_options_async(
        self,
        request: main_models.DuplicateModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.DuplicateModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DuplicateModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DuplicateModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def duplicate_model(
        self,
        request: main_models.DuplicateModelRequest,
    ) -> main_models.DuplicateModelResponse:
        runtime = RuntimeOptions()
        return self.duplicate_model_with_options(request, runtime)

    async def duplicate_model_async(
        self,
        request: main_models.DuplicateModelRequest,
    ) -> main_models.DuplicateModelResponse:
        runtime = RuntimeOptions()
        return await self.duplicate_model_with_options_async(request, runtime)

    def edit_model_with_options(
        self,
        request: main_models.EditModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.EditModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'EditModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.EditModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def edit_model_with_options_async(
        self,
        request: main_models.EditModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.EditModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'EditModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.EditModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def edit_model(
        self,
        request: main_models.EditModelRequest,
    ) -> main_models.EditModelResponse:
        runtime = RuntimeOptions()
        return self.edit_model_with_options(request, runtime)

    async def edit_model_async(
        self,
        request: main_models.EditModelRequest,
    ) -> main_models.EditModelResponse:
        runtime = RuntimeOptions()
        return await self.edit_model_with_options_async(request, runtime)

    def get_bastion_host_certification_with_options(
        self,
        request: main_models.GetBastionHostCertificationRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetBastionHostCertificationResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetBastionHostCertification',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetBastionHostCertificationResponse(),
            self.call_api(params, req, runtime)
        )

    async def get_bastion_host_certification_with_options_async(
        self,
        request: main_models.GetBastionHostCertificationRequest,
        runtime: RuntimeOptions,
    ) -> main_models.GetBastionHostCertificationResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetBastionHostCertification',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetBastionHostCertificationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def get_bastion_host_certification(
        self,
        request: main_models.GetBastionHostCertificationRequest,
    ) -> main_models.GetBastionHostCertificationResponse:
        runtime = RuntimeOptions()
        return self.get_bastion_host_certification_with_options(request, runtime)

    async def get_bastion_host_certification_async(
        self,
        request: main_models.GetBastionHostCertificationRequest,
    ) -> main_models.GetBastionHostCertificationResponse:
        runtime = RuntimeOptions()
        return await self.get_bastion_host_certification_with_options_async(request, runtime)

    def iterate_model_with_options(
        self,
        request: main_models.IterateModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.IterateModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'IterateModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.IterateModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def iterate_model_with_options_async(
        self,
        request: main_models.IterateModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.IterateModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'IterateModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.IterateModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def iterate_model(
        self,
        request: main_models.IterateModelRequest,
    ) -> main_models.IterateModelResponse:
        runtime = RuntimeOptions()
        return self.iterate_model_with_options(request, runtime)

    async def iterate_model_async(
        self,
        request: main_models.IterateModelRequest,
    ) -> main_models.IterateModelResponse:
        runtime = RuntimeOptions()
        return await self.iterate_model_with_options_async(request, runtime)

    def offline_model_with_options(
        self,
        request: main_models.OfflineModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.OfflineModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'OfflineModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.OfflineModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def offline_model_with_options_async(
        self,
        request: main_models.OfflineModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.OfflineModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'OfflineModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.OfflineModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def offline_model(
        self,
        request: main_models.OfflineModelRequest,
    ) -> main_models.OfflineModelResponse:
        runtime = RuntimeOptions()
        return self.offline_model_with_options(request, runtime)

    async def offline_model_async(
        self,
        request: main_models.OfflineModelRequest,
    ) -> main_models.OfflineModelResponse:
        runtime = RuntimeOptions()
        return await self.offline_model_with_options_async(request, runtime)

    def online_model_with_options(
        self,
        request: main_models.OnlineModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.OnlineModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'OnlineModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.OnlineModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def online_model_with_options_async(
        self,
        request: main_models.OnlineModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.OnlineModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'OnlineModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.OnlineModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def online_model(
        self,
        request: main_models.OnlineModelRequest,
    ) -> main_models.OnlineModelResponse:
        runtime = RuntimeOptions()
        return self.online_model_with_options(request, runtime)

    async def online_model_async(
        self,
        request: main_models.OnlineModelRequest,
    ) -> main_models.OnlineModelResponse:
        runtime = RuntimeOptions()
        return await self.online_model_with_options_async(request, runtime)

    def parse_expression_parameters_with_options(
        self,
        request: main_models.ParseExpressionParametersRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ParseExpressionParametersResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.expression):
            query['Expression'] = request.expression
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ParseExpressionParameters',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ParseExpressionParametersResponse(),
            self.call_api(params, req, runtime)
        )

    async def parse_expression_parameters_with_options_async(
        self,
        request: main_models.ParseExpressionParametersRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ParseExpressionParametersResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.expression):
            query['Expression'] = request.expression
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ParseExpressionParameters',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ParseExpressionParametersResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def parse_expression_parameters(
        self,
        request: main_models.ParseExpressionParametersRequest,
    ) -> main_models.ParseExpressionParametersResponse:
        runtime = RuntimeOptions()
        return self.parse_expression_parameters_with_options(request, runtime)

    async def parse_expression_parameters_async(
        self,
        request: main_models.ParseExpressionParametersRequest,
    ) -> main_models.ParseExpressionParametersResponse:
        runtime = RuntimeOptions()
        return await self.parse_expression_parameters_with_options_async(request, runtime)

    def prepublish_model_with_options(
        self,
        request: main_models.PrepublishModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.PrepublishModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'PrepublishModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.PrepublishModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def prepublish_model_with_options_async(
        self,
        request: main_models.PrepublishModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.PrepublishModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'PrepublishModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.PrepublishModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def prepublish_model(
        self,
        request: main_models.PrepublishModelRequest,
    ) -> main_models.PrepublishModelResponse:
        runtime = RuntimeOptions()
        return self.prepublish_model_with_options(request, runtime)

    async def prepublish_model_async(
        self,
        request: main_models.PrepublishModelRequest,
    ) -> main_models.PrepublishModelResponse:
        runtime = RuntimeOptions()
        return await self.prepublish_model_with_options_async(request, runtime)

    def request_model_file_sync_with_options(
        self,
        request: main_models.RequestModelFileSyncRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RequestModelFileSyncResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RequestModelFileSync',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RequestModelFileSyncResponse(),
            self.call_api(params, req, runtime)
        )

    async def request_model_file_sync_with_options_async(
        self,
        request: main_models.RequestModelFileSyncRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RequestModelFileSyncResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.project_id):
            query['ProjectId'] = request.project_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RequestModelFileSync',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RequestModelFileSyncResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def request_model_file_sync(
        self,
        request: main_models.RequestModelFileSyncRequest,
    ) -> main_models.RequestModelFileSyncResponse:
        runtime = RuntimeOptions()
        return self.request_model_file_sync_with_options(request, runtime)

    async def request_model_file_sync_async(
        self,
        request: main_models.RequestModelFileSyncRequest,
    ) -> main_models.RequestModelFileSyncResponse:
        runtime = RuntimeOptions()
        return await self.request_model_file_sync_with_options_async(request, runtime)

    def rollback_model_with_options(
        self,
        request: main_models.RollbackModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RollbackModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RollbackModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RollbackModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def rollback_model_with_options_async(
        self,
        request: main_models.RollbackModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.RollbackModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RollbackModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RollbackModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def rollback_model(
        self,
        request: main_models.RollbackModelRequest,
    ) -> main_models.RollbackModelResponse:
        runtime = RuntimeOptions()
        return self.rollback_model_with_options(request, runtime)

    async def rollback_model_async(
        self,
        request: main_models.RollbackModelRequest,
    ) -> main_models.RollbackModelResponse:
        runtime = RuntimeOptions()
        return await self.rollback_model_with_options_async(request, runtime)

    def test_model_with_options(
        self,
        request: main_models.TestModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def test_model_with_options_async(
        self,
        request: main_models.TestModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def test_model(
        self,
        request: main_models.TestModelRequest,
    ) -> main_models.TestModelResponse:
        runtime = RuntimeOptions()
        return self.test_model_with_options(request, runtime)

    async def test_model_async(
        self,
        request: main_models.TestModelRequest,
    ) -> main_models.TestModelResponse:
        runtime = RuntimeOptions()
        return await self.test_model_with_options_async(request, runtime)

    def test_pre_model_with_options(
        self,
        request: main_models.TestPreModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestPreModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestPreModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestPreModelResponse(),
            self.call_api(params, req, runtime)
        )

    async def test_pre_model_with_options_async(
        self,
        request: main_models.TestPreModelRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestPreModelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestPreModel',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestPreModelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def test_pre_model(
        self,
        request: main_models.TestPreModelRequest,
    ) -> main_models.TestPreModelResponse:
        runtime = RuntimeOptions()
        return self.test_pre_model_with_options(request, runtime)

    async def test_pre_model_async(
        self,
        request: main_models.TestPreModelRequest,
    ) -> main_models.TestPreModelResponse:
        runtime = RuntimeOptions()
        return await self.test_pre_model_with_options_async(request, runtime)

    def test_process_expression_with_options(
        self,
        request: main_models.TestProcessExpressionRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestProcessExpressionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.expression):
            query['Expression'] = request.expression
        if not DaraCore.is_null(request.params):
            query['Params'] = request.params
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestProcessExpression',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestProcessExpressionResponse(),
            self.call_api(params, req, runtime)
        )

    async def test_process_expression_with_options_async(
        self,
        request: main_models.TestProcessExpressionRequest,
        runtime: RuntimeOptions,
    ) -> main_models.TestProcessExpressionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.expression):
            query['Expression'] = request.expression
        if not DaraCore.is_null(request.params):
            query['Params'] = request.params
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TestProcessExpression',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TestProcessExpressionResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def test_process_expression(
        self,
        request: main_models.TestProcessExpressionRequest,
    ) -> main_models.TestProcessExpressionResponse:
        runtime = RuntimeOptions()
        return self.test_process_expression_with_options(request, runtime)

    async def test_process_expression_async(
        self,
        request: main_models.TestProcessExpressionRequest,
    ) -> main_models.TestProcessExpressionResponse:
        runtime = RuntimeOptions()
        return await self.test_process_expression_with_options_async(request, runtime)

    def update_module_basic_info_with_options(
        self,
        request: main_models.UpdateModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.UpdateModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.customer_module_name):
            query['CustomerModuleName'] = request.customer_module_name
        if not DaraCore.is_null(request.description):
            query['Description'] = request.description
        if not DaraCore.is_null(request.module_type):
            query['ModuleType'] = request.module_type
        if not DaraCore.is_null(request.store_path):
            query['StorePath'] = request.store_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateModuleBasicInfoResponse(),
            self.call_api(params, req, runtime)
        )

    async def update_module_basic_info_with_options_async(
        self,
        request: main_models.UpdateModuleBasicInfoRequest,
        runtime: RuntimeOptions,
    ) -> main_models.UpdateModuleBasicInfoResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.customer_module_name):
            query['CustomerModuleName'] = request.customer_module_name
        if not DaraCore.is_null(request.description):
            query['Description'] = request.description
        if not DaraCore.is_null(request.module_type):
            query['ModuleType'] = request.module_type
        if not DaraCore.is_null(request.store_path):
            query['StorePath'] = request.store_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateModuleBasicInfo',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateModuleBasicInfoResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def update_module_basic_info(
        self,
        request: main_models.UpdateModuleBasicInfoRequest,
    ) -> main_models.UpdateModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return self.update_module_basic_info_with_options(request, runtime)

    async def update_module_basic_info_async(
        self,
        request: main_models.UpdateModuleBasicInfoRequest,
    ) -> main_models.UpdateModuleBasicInfoResponse:
        runtime = RuntimeOptions()
        return await self.update_module_basic_info_with_options_async(request, runtime)

    def validate_model_file_with_options(
        self,
        request: main_models.ValidateModelFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ValidateModelFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.file_path):
            query['FilePath'] = request.file_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ValidateModelFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ValidateModelFileResponse(),
            self.call_api(params, req, runtime)
        )

    async def validate_model_file_with_options_async(
        self,
        request: main_models.ValidateModelFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ValidateModelFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.file_path):
            query['FilePath'] = request.file_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ValidateModelFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ValidateModelFileResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def validate_model_file(
        self,
        request: main_models.ValidateModelFileRequest,
    ) -> main_models.ValidateModelFileResponse:
        runtime = RuntimeOptions()
        return self.validate_model_file_with_options(request, runtime)

    async def validate_model_file_async(
        self,
        request: main_models.ValidateModelFileRequest,
    ) -> main_models.ValidateModelFileResponse:
        runtime = RuntimeOptions()
        return await self.validate_model_file_with_options_async(request, runtime)

    def validate_test_file_with_options(
        self,
        request: main_models.ValidateTestFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ValidateTestFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.file_path):
            query['FilePath'] = request.file_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ValidateTestFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ValidateTestFileResponse(),
            self.call_api(params, req, runtime)
        )

    async def validate_test_file_with_options_async(
        self,
        request: main_models.ValidateTestFileRequest,
        runtime: RuntimeOptions,
    ) -> main_models.ValidateTestFileResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.customer_module_id):
            query['CustomerModuleId'] = request.customer_module_id
        if not DaraCore.is_null(request.file_path):
            query['FilePath'] = request.file_path
        req = open_api_util_models.OpenApiRequest(
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ValidateTestFile',
            version = '2025-05-21',
            protocol = 'HTTPS',
            pathname = '/',
            method = 'POST',
            auth_type = 'AK',
            style = 'RPC',
            req_body_type = 'formData',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ValidateTestFileResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def validate_test_file(
        self,
        request: main_models.ValidateTestFileRequest,
    ) -> main_models.ValidateTestFileResponse:
        runtime = RuntimeOptions()
        return self.validate_test_file_with_options(request, runtime)

    async def validate_test_file_async(
        self,
        request: main_models.ValidateTestFileRequest,
    ) -> main_models.ValidateTestFileResponse:
        runtime = RuntimeOptions()
        return await self.validate_test_file_with_options_async(request, runtime)
